@@ -438,10 +438,10 @@ class TailsInstallerWindow(Gtk.ApplicationWindow):
             self.__label_infobar_details.set_use_markup(True)
             self.__infobar.set_message_type(Gtk.MessageType.INFO)
             self.__label_infobar_title.set_text(
-                _("Tails Installer is deprecated"))
+                _("Tails Installer is deprecated in Debian"))
             self.__label_infobar_details.set_markup(
-                _("To install a new Tails, see the <a href='https://tails.boum.org/install/'>installation documentation</a>.\n"
-                  "To upgrade an existing Tails, see the <a href='https://tails.boum.org/upgrade/'>upgrade documentation</a>."))
+                _("To install Tails from scratch, use GNOME Disks instead.\n<a href='https://tails.boum.org/install/linux/usb-overview'>See the installation instructions</a>\n\n"
+                  "To upgrade Tails, do an automatic upgrade from Tails or a manual upgrade from Debian using a second USB stick.\n<a href='https://tails.boum.org/upgrade/tails-overview'>See the manual upgrade instructions</a>"))
             self.__infobar.set_visible(True)
 
     def on_radio_button_source_iso_toggled(self, radio_button):
